---
obj: concept
wiki: https://en.wikipedia.org/wiki/VCard
mime: text/vcard
extension: ["vcf", "vcard"]
rfc: https://datatracker.ietf.org/doc/html/rfc6350
aliases: ["vcf"]
rev: 2024-03-07
---

# vCard
vCard, also known as VCF (Virtual Contact File), is a file format standard for electronic business cards. vCards can be attached to e-mail messages, sent via Multimedia Messaging Service (MMS), on the World Wide Web, instant messaging, NFC or through [QR code](../tools/QR%20Code.md). They can contain name and address information, phone numbers, e-mail addresses, URLs, logos, photographs, and audio clips.

vCard is used as a data interchange format in smartphone contacts, personal digital assistants (PDAs), personal information managers (PIMs) and customer relationship management systems (CRMs). To accomplish these data interchange applications, other "vCard variants" have been used and proposed as "variant standards", each for its specific niche: [XML](XML.md) representation, [JSON](JSON.md) representation, or web pages. 

An example of a simple vCard (from RFC 6350 of August, 2011, abbreviated):
```vcard
BEGIN:VCARD
VERSION:4.0
FN:Simon Perreault
N:Perreault;Simon;;;ing. jr,M.Sc.
BDAY:--0203
GENDER:M
EMAIL;TYPE=work:simon.perreault@viagenie.ca
END:VCARD
```

## Properties
vCard defines the following property types.

All vCards begin with BEGIN:VCARD and end with END:VCARD. All vCards must contain the VERSION property, which specifies the vCard version. VERSION must come immediately after BEGIN, except in the vCard 2.1 standard, which allows it to be anywhere in the vCard. Otherwise, properties can be defined in any order. 

| Name           | Description                                                                                                                                                                                                                                                                                                  | Example                                                                                                                |
| -------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ | ---------------------------------------------------------------------------------------------------------------------- |
| `ADR`          | A structured representation of the physical delivery address for the vCard object.                                                                                                                                                                                                                           | `ADR;TYPE=home:;;123 Main St.;Springfield;IL;12345;USA`                                                                |
| `ANNIVERSARY`  | Defines the person's anniversary.                                                                                                                                                                                                                                                                            | `ANNIVERSARY:19901021`                                                                                                 |
| `BDAY`         | Date of birth of the individual associated with the vCard.                                                                                                                                                                                                                                                   | `BDAY:19700310`                                                                                                        |
| `BEGIN`        | All vCards must start with this property.                                                                                                                                                                                                                                                                    | `BEGIN:VCARD`                                                                                                          |
| `VERSION`      | The version of the vCard specification. In version 4.0, this must come right after the `BEGIN` property.                                                                                                                                                                                                     | `VERSION:4.0`                                                                                                          |
| `CALADRURI`    | A [URL](../internet/URL.md) to use for sending a scheduling request to the person's calendar.                                                                                                                                                                                                                | `CALADRURI:http://example.com/calendar/jdoe`                                                                           |
| `CALURI`       | A [URL](../internet/URL.md) to the person's calendar.                                                                                                                                                                                                                                                        | `CALURI:http://example.com/calendar/jdoe`                                                                              |
| `CATEGORIES`   | A list of "tags" that can be used to describe the object represented by this vCard.                                                                                                                                                                                                                          | `CATEGORIES:swimmer,biker`                                                                                             |
| `CLIENTPIDMAP` | Used for synchronizing different revisions of the same vCard.                                                                                                                                                                                                                                                | `CLIENTPIDMAP:1;urn:uuid:3df403f4-5924-4bb7-b077-3c711d9eb34b`                                                         |
| `EMAIL`        | The address for electronic mail communication with the vCard object.                                                                                                                                                                                                                                         | `EMAIL:johndoe@hotmail.com`                                                                                            |
| `END`          | All vCards must end with this property.                                                                                                                                                                                                                                                                      | `END:VCARD`                                                                                                            |
| `FBURL`        | Defines a [URL](../internet/URL.md) that shows when the person is "free" or "busy" on their calendar.                                                                                                                                                                                                        | `FBURL:http://example.com/fb/jdoe`                                                                                     |
| `FN`           | The formatted name string associated with the vCard object.                                                                                                                                                                                                                                                  | `FN:Dr. John Doe`                                                                                                      |
| `GENDER`       | Defines the person's gender.                                                                                                                                                                                                                                                                                 | `GENDER:F`                                                                                                             |
| `GEO`          | Specifies a latitude and longitude.                                                                                                                                                                                                                                                                          | `GEO:geo:39.95,-75.1667`                                                                                               |
| `KEY`          | The public encryption key associated with the vCard object. It may point to an external [URL](../internet/URL.md), may be plain text, or may be embedded in the vCard as a [Base64](Base64.md) encoded block of text.                                                                                        | `KEY:data:application/pgp-keys;base64,[base64-data]`                                                                   |
| `KIND`         | Defines the type of entity that this vCard represents: `application`, `individual`, `group`, `location` or `organization`; `x-*` values may be used for experimental purposes.                                                                                                                               | `KIND:individual`                                                                                                      |
| `LANG`         | Defines a language that the person speaks.                                                                                                                                                                                                                                                                   | `LANG:fr-CA`                                                                                                           |
| `LOGO`         | An image or graphic of the logo of the organization that is associated with the individual to which the vCard belongs. It may point to an external [URL](../internet/URL.md) or may be embedded in the vCard as a [Base64](Base64.md) encoded block of text.                                                 | `LOGO;ENCODING=BASE64;TYPE=PNG:[base64-data]`                                                                          |
| `MEMBER`       | Defines a member that is part of the group that this vCard represents. Acceptable values include:<br>- a "mailto:" [URL](../internet/URL.md) containing an email address<br>- a UID which references the member's own vCard<br><br>The `KIND` property must be set to `group` in order to use this property. | `MEMBER:urn:uuid:03a0e51f-d1aa-4385-8a53-e29025acd8af`                                                                 |
| `N`            | A structured representation of the name of the person, place or thing associated with the vCard object. Structure recognizes, in order separated by semicolons: Family Name, Given Name, Additional/Middle Names, Honorific Prefixes, and Honorific Suffixes                                                 | `N:Doe;John;;Dr;`                                                                                                      |
| `NICKNAME`     | One or more descriptive/familiar names for the object represented by this vCard.                                                                                                                                                                                                                             | `NICKNAME:Jon,Johnny`                                                                                                  |
| `NOTE`         | Specifies supplemental information or a comment that is associated with the vCard.                                                                                                                                                                                                                           | `NOTE:I am proficient in Tiger-Crane Style,\nand I am more than proficient in the exquisite art of the Samurai sword.` |
| `ORG`          | The name and optionally the unit(s) of the organization associated with the vCard object. This property is based on the X.520 Organization Name attribute and the X.520 Organization Unit attribute.                                                                                                         | `ORG:Google;GMail Team;Spam Detection Squad`                                                                           |
| `PHOTO`        | An image or photograph of the individual associated with the vCard. It may point to an external [URL](../internet/URL.md) or may be embedded in the vCard as a [Base64](Base64.md) encoded block of text.                                                                                                    | `PHOTO;ENCODING=BASE64;TYPE=PNG:[base64-data]`                                                                         |
| `PRODID`       | The identifier for the product that created the vCard object.                                                                                                                                                                                                                                                | `PRODID:-//ONLINE DIRECTORY//NONSGML Version 1//EN`                                                                    |
| `RELATED`      | Another entity that the person is related to. Acceptable values include:<br>- a "mailto:" [URL](../internet/URL.md) containing an email address<br>- a UID which references the person's own vCard<br>- a text value used to specify textual information                                                     | `RELATED;TYPE=friend:urn:uuid:03a0e51f-d1aa-4385-8a53-e29025acd8af`                                                    |
| `REV`          | A timestamp for the last time the vCard was updated.                                                                                                                                                                                                                                                         | `REV:20121201T134211Z`                                                                                                 |
| `ROLE`         | The role, occupation, or business category of the vCard object within an organization.                                                                                                                                                                                                                       | `ROLE:Executive`                                                                                                       |
| `SOURCE`       | A URL that can be used to get the latest version of this vCard.                                                                                                                                                                                                                                              | `SOURCE:http://johndoe.com/vcard.vcf`                                                                                  |
| `TEL`          | The canonical number string for a telephone number for telephony communication with the vCard object.                                                                                                                                                                                                        | `TEL;TYPE=cell:(123) 555-5832`                                                                                         |
| `TITLE`        | Specifies the job title, functional position or function of the individual associated with the vCard object within an organization.                                                                                                                                                                          | `TITLE:V.P. Research and Development`                                                                                  |
| `TZ`           | The time zone of the vCard object.                                                                                                                                                                                                                                                                           | `TZ:America/New_York`                                                                                                  |
| `UID`          | Specifies a value that represents a persistent, globally unique identifier associated with the object.                                                                                                                                                                                                       | `UID:urn:uuid:da418720-3754-4631-a169-db89a02b831b`                                                                    |
| `URL`          | A URL pointing to a website that represents the person in some way.                                                                                                                                                                                                                                          | `URL:http://www.johndoe.com`                                                                                           |
